@@ -16,7 +16,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-H2I_AUTHOR="[@]pkgauthor[@]"
 H2I_DESCRIPTION="[@]pkgdescription[@]"
 H2I="$(basename $0)"
 H2I_BUGREPORT="[@]pkgbugreport[@]"
@@ -50,8 +49,8 @@ eval set -- "$TEMP"
 while [[ -n "$1" ]]
 do
 	case "$1" in
-		-"d" | --"dircategory") H2I_DIRCATEGORY="$2"; shift 2;;
-		-"n" | --"programname") H2I_PROGRAM_NAME="$2"; shift 2;;
+		-"d" | --"dircategory") H2I_INFO_DIRCATEGORY="$2"; shift 2;;
+		-"n" | --"programname") H2I_INFO_PROGRAM_NAME="$2"; shift 2;;
 		-"h" | --"help") h2i_usage; shift;;
 		-"v" | --"version") h2i_version; shift;;
 		--) shift; break;;
@@ -74,7 +73,7 @@ function h2i_parse_usage
 	done
 	IFS=$O
 }
-H2I_USAGE=$(h2i_parse_usage "$H2I_OUTPUT")
+H2I_INFO_USAGE=$(h2i_parse_usage "$H2I_OUTPUT")
 
 # get description
 # comes after usage and ends with a blank line
@@ -92,7 +91,7 @@ function h2i_parse_description
 	H2I_END=$(echo "$1" | grep -nm 1 '^$' | cut -d':' -f1)
 	echo "$1" | sed -n ${H2I_START},${H2I_END}p
 }
-H2I_DESCRIPTION=$(h2i_parse_description "$H2I_OUTPUT")
+H2I_INFO_DESCRIPTION=$(h2i_parse_description "$H2I_OUTPUT")
 
 # get options (starts after the description with the mandatory line for long and short options and ends with the bugreport comment, last line if present)
 function h2i_parse_options
@@ -108,33 +107,33 @@ function h2i_parse_options
 	fi
 	echo "$1" | sed -n ${H2I_START},${H2I_END}p
 }
-H2I_OPTIONS=$(h2i_parse_options "$H2I_OUTPUT")
+H2I_PROGRAM_OPTIONS=$(h2i_parse_options "$H2I_OUTPUT")
 
 # get year
-H2I_YEAR=$(LANG=C date '+%Y')
+H2I_INFO_YEAR=$(LANG=C date '+%Y')
 
 # get author
-if [[ -z $H2I_AUTHOR ]]
-	then H2I_AUTHOR=$(grep $(whoami) /etc/passwd | cut -d':' -f5 | cut -d',' -f1)
+if [[ -z $H2I_INFO_AUTHOR ]]
+	then H2I_INFO_AUTHOR=$(grep $(whoami) /etc/passwd | cut -d':' -f5 | cut -d',' -f1)
 fi
-if [[ -z $H2I_AUTHOR ]]
-	then H2I_AUTHOR="Insert author name here"
+if [[ -z $H2I_INFO_AUTHOR ]]
+	then H2I_INFO_AUTHOR="Insert author name here"
 fi
 
 # get dircategory
-if [[ -z $H2I_DIRCATEGORY ]]
+if [[ -z $H2I_INFO_DIRCATEGORY ]]
 then
-	H2I_DIRCATEGORY="Insert dir category here"
+	H2I_INFO_DIRCATEGORY="Insert dir category here"
 fi
 
 # get program name
-if [[ -z $H2I_PROGRAM_NAME ]]
+if [[ -z $H2I_INFO_PROGRAM_NAME ]]
 then
-	H2I_PROGRAM_NAME="$1"
+	H2I_INFO_PROGRAM_NAME="$1"
 fi
 
 # get examples
-H2I_EXAMPLES="Insert your samples here"
+H2I_INFO_EXAMPLES="Insert your examples here"
 
 
 # convert options to info
@@ -168,10 +167,18 @@ function h2i_options
 			echo "$line"
 		else
 			if(echo "$line" | grep -qe '^  -\w\+')
-			then h2i_parse_args "$line"
+			then
+				if [[ -z $H2I_OPTIONS_STARTED ]]
+				then echo "@table @code"; H2I_OPTIONS_STARTED="true"
+				fi
+				h2i_parse_args "$line"
 			else
 				if(echo "$line" | grep -qe '^      --\w\+')
-				then h2i_parse_args "$line"
+				then
+					if [[ -z $H2I_OPTIONS_STARTED ]]
+					then echo "@table @code"; H2I_OPTIONS_STARTED="true"
+					fi
+					h2i_parse_args "$line"
 				else
 					if(echo "$line" | grep -q '^\w\+')
 					then 
@@ -204,10 +211,19 @@ function h2i_options
 	if [[ -n $H2I_OPTIONS_INFO_STARTED ]]; then echo "@end verbatim"; else printf "@end table"; fi
 	IFS=$O
 }
-H2I_OPTIONS_TEXI=$(h2i_options "$H2I_OPTIONS")
+H2I_INFO_OPTIONS=$(h2i_options "$H2I_PROGRAM_OPTIONS")
 
 # convert bugreport addres to info
-H2I_INFOBUGREPORT=$(echo "$H2I_BUGREPORT" | sed -re 's,(\w@),\1@,g')
+function h2i_bugreport()
+{
+	H2I_COMMENT=$(tail -n 1 <<< "$1")
+	if grep -qi "report bugs" <<<"$H2I_COMMENT"
+	then echo "$H2I_COMMENT" | cut -d'<' -f2 | cut -d'>' -f1| sed -re 's,(\w@),\1@,g'
+	else echo "Insert your mail address here"
+	fi
+}
+
+H2I_INFO_BUGREPORT=$(h2i_bugreport "$H2I_OUTPUT")
 
 # generate the texi file
 cat >"$1.texi" <<EOF
@@ -220,11 +236,11 @@ cat >"$1.texi" <<EOF
 @syncodeindex pg cp
 @comment %**end of header
 @copying
-This manual is for $H2I_PROGRAM_NAME
+This manual is for $H2I_INFO_PROGRAM_NAME
 (version @value{VERSION}, @value{UPDATED}),
-which is a program that $H2I_DESCRIPTION
+which is a program that $H2I_INFO_DESCRIPTION
 
-Copyright @copyright{} $H2I_YEAR $H2I_AUTHOR
+Copyright @copyright{} $H2I_INFO_YEAR $H2I_INFO_AUTHOR
 
 @quotation
 Permission is granted to copy, distribute, and/or modify this document
@@ -239,15 +255,15 @@ License.''
 this Manual, like GNU software.''
 @end quotation
 @end copying
-@dircategory $H2I_DIRCATEGORY
+@dircategory $H2I_INFO_DIRCATEGORY
 @direntry
-* $H2I_PROGRAM_NAME: ($1). $H2I_DESCRIPTION
+* $H2I_INFO_PROGRAM_NAME: ($1). $H2I_INFO_DESCRIPTION
 @end direntry
 
 @titlepage
-@title $H2I_PROGRAM_NAME
+@title $H2I_INFO_PROGRAM_NAME
 @subtitle for version @value{VERSION}, @value{UPDATED}
-@author $H2I_AUTHOR (@email{$H2I_INFOBUGREPORT})
+@author $H2I_INFO_AUTHOR (@email{$H2I_INFO_BUGREPORT})
 @page
 @vskip 0pt plus 1filll
 @insertcopying
@@ -257,7 +273,7 @@ this Manual, like GNU software.''
 
 @ifnottex
 @node Top
-@top $H2I_PROGRAM_NAME
+@top $H2I_INFO_PROGRAM_NAME
 @insertcopying
 @end ifnottex
 
@@ -273,31 +289,31 @@ this Manual, like GNU software.''
 @chapter Introduction
 @pindex introduction
 @cindex introduction
-$H2I_DESCRIPTION
+$H2I_INFO_DESCRIPTION
 
 @node Invoking $1
 @chapter Invoking $1
 @pindex invoking
 @cindex invoking @command{$1}
 @verbatim
-$H2I_USAGE
+$H2I_INFO_USAGE
 @end verbatim
 
 @command{$1} may be invoked with the following command-line options:
 
-$H2I_OPTIONS_TEXI
+$H2I_INFO_OPTIONS
 
 @node Examples
 @chapter Examples
 @pindex examples
 @cindex examples
-$H2I_EXAMPLES
+$H2I_INFO_EXAMPLES
 
 @node Reporting Bugs
 @chapter Reporting Bugs
 @pindex bugs
 @cindex reporting bugs
-Email bug reports to @email{$H2I_INFOBUGREPORT}. Be sure to include the word @dfn{$1} somewhere in the @code{Subject:} field. Also, please include the output of @samp{$1 --version} in the body of your report if at all possible.
+Email bug reports to @email{$H2I_INFO_BUGREPORT}. Be sure to include the word @dfn{$1} somewhere in the @code{Subject:} field. Also, please include the output of @samp{$1 --version} in the body of your report if at all possible.
 
 
 @node Copying This Manual
